"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProjectRecord = void 0;
const errors_1 = require("../utlils/errors");
const db_1 = require("../utlils/db");
const uuid_1 = require("uuid");
class ProjectRecord {
    constructor(obj) {
        if (!obj.projectName || obj.projectName.length > 30) {
            throw new errors_1.ValidationError("Nazwa projektu nie może być pusta, ani przekraczać 30 znaków.");
        }
        this.id = obj.id;
        this.projectName = obj.projectName;
        this.createdAt = obj.createdAt;
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `projects` WHERE id = :id", {
                id,
            });
            return results.length === 0 ? null : new ProjectRecord(results[0]);
        });
    }
    static getAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `projects`");
            return results.length === 0 ? [] : results.map(obj => new ProjectRecord(obj));
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            yield db_1.pool.execute("INSERT INTO `projects`(`id`, `projectName`) VALUES(:id, :projectName)", {
                id: this.id,
                projectName: this.projectName,
            });
            return this.id;
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `projects` WHERE `id` = :id", {
                id: this.id,
            });
        });
    }
}
exports.ProjectRecord = ProjectRecord;
//# sourceMappingURL=project.record.js.map