"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TaskRecord = void 0;
const errors_1 = require("../utlils/errors");
const db_1 = require("../utlils/db");
const uuid_1 = require("uuid");
class TaskRecord {
    constructor(obj) {
        // console.log(obj.taskName);
        if (!obj.taskName || obj.taskName.length > 50) {
            throw new errors_1.ValidationError("Nazwa zadania nie może być pusta, ani przekraczać 50 znaków.");
        }
        this.id = obj.id;
        this.taskName = obj.taskName;
        this.projectId = obj.projectId;
        this.completed = obj.completed;
        this.createdAt = obj.createdAt;
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `tasks` WHERE id = :id", {
                id,
            });
            return results.length === 0 ? null : new TaskRecord(results[0]);
        });
    }
    static getAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `tasks`");
            return results.length === 0 ? [] : results.map(obj => new TaskRecord(obj));
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            yield db_1.pool.execute("INSERT INTO `tasks`(`id`, `taskName`, `completed`, `projectId`) VALUES(:id, :taskName, :completed, (SELECT `id` FROM `projects` WHERE id = :projectId))", {
                id: this.id,
                taskName: this.taskName,
                completed: this.completed,
                projectId: this.projectId,
            });
            return this.id;
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("UPDATE `tasks` SET `taskName` = :taskName, `completed` = :completed, `projectId` = :projectId WHERE `id` = :id", {
                id: this.id,
                taskName: this.taskName,
                completed: this.completed,
                projectId: this.projectId,
            });
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `tasks` WHERE `id` = :id", {
                id: this.id,
            });
        });
    }
}
exports.TaskRecord = TaskRecord;
//# sourceMappingURL=task.record.js.map